@@ -1,17 +1,20 @@
 OC.L10N.register(
     "deck",
     {
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
+    "No file was uploaded" : "Nulle file esseva incargate",
+    "Missing a temporary folder" : "Il manca un dossier temporari",
     "Finished" : "Finite",
     "To review" : "A revider",
     "Action needed" : "Action necessari",
     "Later" : "Depost",
     "Done" : "Preste",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
-    "No file was uploaded" : "Nulle file esseva incargate",
-    "Missing a temporary folder" : "Il manca un dossier temporari",
+    "Attachments" : "Attachamentos",
     "Cancel" : "Cancellar",
     "Completed" : "Completate",
     "Details" : "Detalios",
+    "General" : "General",
+    "Search" : "Cercar",
     "Sharing" : "Compartente",
     "Tags" : "Etiquettas",
     "Activity" : "Activitate",
@@ -23,26 +26,25 @@ OC.L10N.register(
     "Edit" : "Modificar",
     "Members" : "Membros",
     "Download" : "Discargar",
-    "Attachments" : "Attachamentos",
-    "Comments" : "Commentarios",
     "Modified" : "Modificate",
-    "Save" : "Salveguardar",
+    "Comments" : "Commentarios",
+    "Created:" : "Create:",
     "Reply" : "Responder",
     "Update" : "Actualisation",
-    "Created:" : "Create:",
     "Description" : "Description",
     "(group)" : "(gruppo)",
     "seconds ago" : "secundas passate",
-    "Keyboard shortcuts" : "Combinationes de claves",
-    "Keyboard shortcut" : "Combination de claves",
-    "Search" : "Cercar",
     "Shared with you" : "Compartite con te",
     "No notifications" : "Nulle notificationes",
     "Advanced options" : "Optiones avantiate",
-    "Today" : "Hodie",
-    "Tomorrow" : "Deman",
+    "Export" : "Exportar",
     "Close" : "Clauder",
     "Share" : "Compartir",
-    "Personal" : "Personal"
+    "Personal" : "Personal",
+    "Save" : "Salveguardar",
+    "Keyboard shortcuts" : "Combinationes de claves",
+    "Keyboard shortcut" : "Combination de claves",
+    "Today" : "Hodie",
+    "Tomorrow" : "Deman"
 },
 "nplurals=2; plural=(n != 1);");
