@@ -31,6 +31,9 @@ OC.L10N.register(
     "Next 30 days" : "Keyingi 30 kun",
     "No due date" : "Muddati yo'q",
     "Details" : "Details",
+    "General" : "Umumiy",
+    "Appearance" : "Tashqi ko'rinish",
+    "Search" : "Qidirish",
     "Sharing" : "Ulashish",
     "Tags" : "Tags",
     "Activity" : "Faollik",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Download" : "Yuklab olish",
     "Modified" : "Modified",
     "Comments" : "Comments",
-    "Save" : "Saqlash",
     "In reply to" : "ga javoban",
     "Reply" : "Javob bering",
     "Update" : "Update",
@@ -55,10 +57,9 @@ OC.L10N.register(
     "Edit title" : "Sarlavhani tahrirlash",
     "Delete card" : "Kartani o'chirish",
     "seconds ago" : "seconds ago",
-    "Keyboard shortcuts" : "Klaviatura yorliqlari",
-    "Search" : "Qidirish",
     "Archived boards" : "Arxivlangan taxtalar",
     "Shared with you" : "Shared with you",
+    "Cancel edit" : "Tahrirni bekor qilish",
     "No reminder" : "Eslatma yo'q",
     "Edit board" : "Tahrirlash paneli",
     "Clone board" : "Klon taxtasi",
@@ -73,6 +74,8 @@ OC.L10N.register(
     "Due date" : "Muddati",
     "Share" : "Ulashish",
     "Personal" : "Personal",
+    "Save" : "Saqlash",
+    "Keyboard shortcuts" : "Klaviatura yorliqlari",
     "Today" : "Today",
     "Tomorrow" : "Ertaga"
 },
