@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -100,7 +101,7 @@ class ActivityManager {
 		StackMapper $stackMapper,
 		AclMapper $aclMapper,
 		IFactory $l10nFactory,
-		?string $userId
+		?string $userId,
 	) {
 		$this->manager = $manager;
 		$this->permissionService = $permissionsService;
@@ -405,7 +406,7 @@ class ActivityManager {
 
 			if ($subject === self::SUBJECT_CARD_UPDATE_DESCRIPTION && isset($params['after'])) {
 				$newContent = $params['after'];
-				unset($params['before'], $params['after'], $params['card']['description']);
+				unset($params['before'], $params['after'], $params['card']['description'], $params['card']['descriptionPrev']);
 
 				$params['after'] = mb_substr($newContent, 0, self::SHORTENED_DESCRIPTION_MAX_LENGTH);
 				if (mb_strlen($newContent) > self::SHORTENED_DESCRIPTION_MAX_LENGTH) {
@@ -484,7 +485,7 @@ class ActivityManager {
 					$objectId = $entity->getObjectId();
 					break;
 				default:
-					throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+					throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 			}
 			return $this->cardMapper->find($objectId);
 		}
@@ -499,11 +500,11 @@ class ActivityManager {
 					$objectId = $entity->getBoardId();
 					break;
 				default:
-					throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+					throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 			}
 			return $this->boardMapper->find($objectId);
 		}
-		throw new InvalidArgumentException('No entity relation present for '. $className . ' to ' . $objectType);
+		throw new InvalidArgumentException('No entity relation present for ' . $className . ' to ' . $objectType);
 	}
 
 	private function findDetailsForStack($stackId) {
@@ -515,10 +516,17 @@ class ActivityManager {
 		];
 	}
 
-	private function findDetailsForCard($cardId, $subject = null) {
+	private function findDetailsForCard(int $cardId, ?string $subject = null): array {
 		$card = $this->cardMapper->find($cardId);
 		$stack = $this->stackMapper->find($card->getStackId());
 		$board = $this->boardMapper->find($stack->getBoardId());
+
+		// Reduce the data size in activity table
+		$boardArray = [
+			'id' => $board->getId(),
+			'title' => $board->getTitle(),
+		];
+
 		if ($subject !== self::SUBJECT_CARD_UPDATE_DESCRIPTION) {
 			$card = [
 				'id' => $card->getId(),
@@ -529,7 +537,7 @@ class ActivityManager {
 		return [
 			'card' => $card,
 			'stack' => $stack,
-			'board' => $board
+			'board' => $boardArray,
 		];
 	}
 
