@@ -7,8 +7,10 @@
 
 namespace OCA\Deck\Controller;
 
+use OCA\Deck\Db\Label;
 use OCA\Deck\Service\LabelService;
 use OCP\AppFramework\Controller;
+use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\IRequest;
 
 class LabelController extends Controller {
@@ -20,34 +22,18 @@ class LabelController extends Controller {
 		parent::__construct($appName, $request);
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @param $title
-	 * @param $color
-	 * @param $boardId
-	 * @return \OCP\AppFramework\Db\Entity
-	 */
-	public function create($title, $color, $boardId) {
+	#[NoAdminRequired]
+	public function create(string $title, string $color, int $boardId): Label {
 		return $this->labelService->create($title, $color, $boardId);
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @param $id
-	 * @param $title
-	 * @param $color
-	 * @return \OCP\AppFramework\Db\Entity
-	 */
-	public function update($id, $title, $color) {
+	#[NoAdminRequired]
+	public function update(int $id, string $title, string $color): Label {
 		return $this->labelService->update($id, $title, $color);
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @param $labelId
-	 * @return \OCP\AppFramework\Db\Entity
-	 */
-	public function delete($labelId) {
+	#[NoAdminRequired]
+	public function delete(int $labelId): Label {
 		return $this->labelService->delete($labelId);
 	}
 }
