@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -75,12 +76,42 @@ class AssignmentMapper extends DeckMapper implements IPermissionMapper {
 		return $this->findEntities($qb);
 	}
 
+	public function deleteByParticipantOnBoard(string $participant, int $boardId, $type = Assignment::TYPE_USER) {
+		// Step 1: Get all card IDs for the board that have assignments for this participant
+		// This avoids MySQL Error 1093 by separating the SELECT from the DELETE operation
+		$cardIdQuery = $this->db->getQueryBuilder();
+		$cardIdQuery->select('a.card_id')
+			->from('deck_assigned_users', 'a')
+			->innerJoin('a', 'deck_cards', 'c', 'c.id = a.card_id')
+			->innerJoin('c', 'deck_stacks', 's', 's.id = c.stack_id')
+			->where($cardIdQuery->expr()->eq('a.participant', $cardIdQuery->createNamedParameter($participant, IQueryBuilder::PARAM_STR)))
+			->andWhere($cardIdQuery->expr()->eq('s.board_id', $cardIdQuery->createNamedParameter($boardId, IQueryBuilder::PARAM_INT)))
+			->andWhere($cardIdQuery->expr()->eq('a.type', $cardIdQuery->createNamedParameter($type, IQueryBuilder::PARAM_INT)));
 
-	public function isOwner($userId, $id): bool {
+		$result = $cardIdQuery->executeQuery();
+		$cardIds = [];
+		while ($row = $result->fetch()) {
+			$cardIds[] = $row['card_id'];
+		}
+		$result->closeCursor();
+
+		// Step 2: If we have card IDs, delete the assignments
+		if (!empty($cardIds)) {
+			$deleteQuery = $this->db->getQueryBuilder();
+			$deleteQuery->delete('deck_assigned_users')
+				->where($deleteQuery->expr()->eq('participant', $deleteQuery->createNamedParameter($participant, IQueryBuilder::PARAM_STR)))
+				->andWhere($deleteQuery->expr()->eq('type', $deleteQuery->createNamedParameter($type, IQueryBuilder::PARAM_INT)))
+				->andWhere($deleteQuery->expr()->in('card_id', $deleteQuery->createNamedParameter($cardIds, IQueryBuilder::PARAM_INT_ARRAY)));
+			$deleteQuery->executeStatement();
+		}
+	}
+
+
+	public function isOwner(string $userId, int $id): bool {
 		return $this->cardMapper->isOwner($userId, $id);
 	}
 
-	public function findBoardId($id): ?int {
+	public function findBoardId(int $id): ?int {
 		return $this->cardMapper->findBoardId($id);
 	}
 
@@ -92,6 +123,9 @@ class AssignmentMapper extends DeckMapper implements IPermissionMapper {
 	 * @throws NotFoundException
 	 */
 	public function insert(Entity $entity): Entity {
+		if (!($entity instanceof Assignment)) {
+			throw new \LogicException('Trying to insert a ' . get_class($entity) . ' in the assignment mapper');
+		}
 		$origin = $this->getOrigin($entity);
 		if ($origin === null) {
 			throw new NotFoundException('No origin found for assignment');
@@ -110,7 +144,7 @@ class AssignmentMapper extends DeckMapper implements IPermissionMapper {
 		});
 	}
 
-	public function isUserAssigned($cardId, $userId): bool {
+	public function isUserAssigned(int $cardId, string $userId): bool {
 		$assignments = $this->findAll($cardId);
 		foreach ($assignments as $assignment) {
 			$origin = $this->getOrigin($assignment);
