@@ -64,10 +64,14 @@ class CardService {
 	) {
 	}
 
-	public function enrichCards($cards) {
+	/**
+	 * @param Card[] $cards
+	 * @return CardDetails[]
+	 */
+	public function enrichCards(array $cards): array {
 		$user = $this->userManager->get($this->userId);
 
-		$cardIds = array_map(function (Card $card) use ($user) {
+		$cardIds = array_map(function (Card $card) use ($user): int {
 			// Everything done in here might be heavy as it is executed for every card
 			$cardId = $card->getId();
 			$this->cardMapper->mapOwner($card);
@@ -120,7 +124,8 @@ class CardService {
 		);
 	}
 
-	public function fetchDeleted($boardId) {
+	/** @return Card[] */
+	public function fetchDeleted($boardId): array {
 		$this->cardServiceValidator->check(compact('boardId'));
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		$cards = $this->cardMapper->findDeleted($boardId);
@@ -129,13 +134,12 @@ class CardService {
 	}
 
 	/**
-	 * @return \OCA\Deck\Db\RelationalEntity
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function find(int $cardId) {
+	public function find(int $cardId): Card {
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_READ);
 		$card = $this->cardMapper->find($cardId);
 		[$card] = $this->enrichCards([$card]);
@@ -152,7 +156,10 @@ class CardService {
 		return $card;
 	}
 
-	public function findCalendarEntries($boardId) {
+	/**
+	 * @return Card[]
+	 */
+	public function findCalendarEntries(int $boardId): array {
 		try {
 			$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		} catch (NoPermissionException $e) {
@@ -163,20 +170,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $title
-	 * @param $stackId
-	 * @param $type
-	 * @param integer $order
-	 * @param $description
-	 * @param $owner
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadrequestException
 	 */
-	public function create($title, $stackId, $type, $order, $owner, $description = '', $duedate = null) {
+	public function create(string $title, int $stackId, string $type, int $order, string $owner, string $description = '', $duedate = null): Card {
 		$this->cardServiceValidator->check(compact('title', 'stackId', 'type', 'order', 'owner'));
 
 		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_EDIT);
@@ -203,19 +203,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function delete($id) {
-		if (is_numeric($id) === false) {
-			throw new BadRequestException('card id must be a number');
-		}
-
+	public function delete(int $id): Card {
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
 		if ($this->boardService->isArchived($this->cardMapper, $id)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
@@ -233,25 +227,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @param $title
-	 * @param $stackId
-	 * @param $type
-	 * @param $owner
-	 * @param $description
-	 * @param $order
-	 * @param $duedate
-	 * @param $deletedAt
-	 * @param $archived
-	 * @param $done
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function update($id, $title, $stackId, $type, $owner, $description = '', $order = 0, $duedate = null, $deletedAt = null, $archived = null, ?OptionalNullableValue $done = null) {
+	public function update(int $id, string $title, int $stackId, string $type, string $owner, string $description = '', int $order = 0, ?string $duedate = null, ?int $deletedAt = null, ?bool $archived = null, ?OptionalNullableValue $done = null): Card {
 		$this->cardServiceValidator->check(compact('id', 'title', 'stackId', 'type', 'owner', 'order'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT, allowDeletedCard: true);
@@ -398,16 +380,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @param $title
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function rename($id, $title) {
+	public function rename(int $id, string $title): Card {
 		$this->cardServiceValidator->check(compact('id', 'title'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
@@ -429,17 +408,14 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @param $stackId
-	 * @param $order
-	 * @return array
+	 * @return list<Card>
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function reorder(int $id, int $stackId, int $order) {
+	public function reorder(int $id, int $stackId, int $order): array {
 		$this->cardServiceValidator->check(compact('id', 'stackId', 'order'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
@@ -488,15 +464,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function archive($id) {
+	public function archive(int $id): Card {
 		$this->cardServiceValidator->check(compact('id'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $id, Acl::PERMISSION_EDIT);
@@ -517,15 +491,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @return \OCP\AppFramework\Db\Entity
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function unarchive($id) {
+	public function unarchive(int $id): Card {
 		$this->cardServiceValidator->check(compact('id'));
 
 
@@ -546,8 +518,6 @@ class CardService {
 	}
 
 	/**
-	 * @param $id
-	 * @return \OCA\Deck\Db\Card
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
@@ -599,15 +569,13 @@ class CardService {
 	}
 
 	/**
-	 * @param $cardId
-	 * @param $labelId
 	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function assignLabel($cardId, $labelId) {
+	public function assignLabel(int $cardId, int $labelId): Card {
 		$this->cardServiceValidator->check(compact('cardId', 'labelId'));
 
 		$this->permissionService->checkPermission($this->cardMapper, $cardId, Acl::PERMISSION_EDIT);
@@ -629,18 +597,16 @@ class CardService {
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_LABEL_ASSIGN, ['label' => $label]);
 
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		return $card;
 	}
 
 	/**
-	 * @param $cardId
-	 * @param $labelId
-	 * @throws StatusException
 	 * @throws \OCA\Deck\NoPermissionException
 	 * @throws \OCP\AppFramework\Db\DoesNotExistException
 	 * @throws \OCP\AppFramework\Db\MultipleObjectsReturnedException
 	 * @throws BadRequestException
 	 */
-	public function removeLabel($cardId, $labelId) {
+	public function removeLabel(int $cardId, int $labelId): Card {
 		$this->cardServiceValidator->check(compact('cardId', 'labelId'));
 
 
@@ -660,6 +626,7 @@ class CardService {
 		$this->activityManager->triggerEvent(ActivityManager::DECK_OBJECT_CARD, $card, ActivityManager::SUBJECT_LABEL_UNASSING, ['label' => $label]);
 
 		$this->eventDispatcher->dispatchTyped(new CardUpdatedEvent($card));
+		return $card;
 	}
 
 	public function getCardUrl(int $cardId): string {
