@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -29,7 +30,7 @@ class ConfigService {
 
 	public function __construct(
 		IConfig $config,
-		IGroupManager $groupManager
+		IGroupManager $groupManager,
 	) {
 		$this->groupManager = $groupManager;
 		$this->config = $config;
@@ -47,7 +48,8 @@ class ConfigService {
 	}
 
 	public function getAll(): array {
-		if ($this->getUserId() === null) {
+		$userId = $this->getUserId();
+		if ($userId === null) {
 			return [];
 		}
 
@@ -56,7 +58,7 @@ class ConfigService {
 			'cardDetailsInModal' => $this->isCardDetailsInModal(),
 			'cardIdBadge' => $this->isCardIdBadgeEnabled()
 		];
-		if ($this->groupManager->isAdmin($this->getUserId())) {
+		if ($this->groupManager->isAdmin($userId)) {
 			$data['groupLimit'] = $this->get('groupLimit');
 		}
 		return $data;
@@ -94,44 +96,48 @@ class ConfigService {
 	}
 
 	public function isCalendarEnabled(?int $boardId = null): bool {
-		if ($this->getUserId() === null) {
+		$userId = $this->getUserId();
+		if ($userId === null) {
 			return false;
 		}
 
 		$appConfigState = $this->config->getAppValue(Application::APP_ID, 'calendar', 'yes') === 'yes';
-		$defaultState = (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'calendar', $appConfigState);
+		$defaultState = (bool)$this->config->getUserValue($userId, Application::APP_ID, 'calendar', $appConfigState);
 		if ($boardId === null) {
 			return $defaultState;
 		}
 
-		return (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'board:' . $boardId . ':calendar', $defaultState);
+		return (bool)$this->config->getUserValue($userId, Application::APP_ID, 'board:' . $boardId . ':calendar', $defaultState);
 	}
 
 	public function isCardDetailsInModal(?int $boardId = null): bool {
-		if ($this->getUserId() === null) {
+		$userId = $this->getUserId();
+		if ($userId === null) {
 			return false;
 		}
 
-		$defaultState = (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'cardDetailsInModal', true);
+		$defaultState = (bool)$this->config->getUserValue($userId, Application::APP_ID, 'cardDetailsInModal', true);
 		if ($boardId === null) {
 			return $defaultState;
 		}
 
-		return (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'board:' . $boardId . ':cardDetailsInModal', $defaultState);
+		return (bool)$this->config->getUserValue($userId, Application::APP_ID, 'board:' . $boardId . ':cardDetailsInModal', $defaultState);
 	}
 
 	public function isCardIdBadgeEnabled(): bool {
-		if ($this->getUserId() === null) {
+		$userId = $this->getUserId();
+		if ($userId === null) {
 			return false;
 		}
 		$appConfigState = $this->config->getAppValue(Application::APP_ID, 'cardIdBadge', 'yes') === 'no';
-		$defaultState = (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'cardIdBadge', $appConfigState);
+		$defaultState = (bool)$this->config->getUserValue($userId, Application::APP_ID, 'cardIdBadge', $appConfigState);
 
-		return (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'cardIdBadge', $defaultState);
+		return (bool)$this->config->getUserValue($userId, Application::APP_ID, 'cardIdBadge', $defaultState);
 	}
 
 	public function set($key, $value) {
-		if ($this->getUserId() === null) {
+		$userId = $this->getUserId();
+		if ($userId === null) {
 			throw new NoPermissionException('Must be logged in to set user config');
 		}
 
@@ -139,21 +145,21 @@ class ConfigService {
 		[$scope] = explode(':', $key, 2);
 		switch ($scope) {
 			case 'groupLimit':
-				if (!$this->groupManager->isAdmin($this->getUserId())) {
+				if (!$this->groupManager->isAdmin($userId)) {
 					throw new NoPermissionException('You must be admin to set the group limit');
 				}
 				$result = $this->setGroupLimit($value);
 				break;
 			case 'calendar':
-				$this->config->setUserValue($this->getUserId(), Application::APP_ID, 'calendar', (string)$value);
+				$this->config->setUserValue($userId, Application::APP_ID, 'calendar', (string)$value);
 				$result = $value;
 				break;
 			case 'cardDetailsInModal':
-				$this->config->setUserValue($this->getUserId(), Application::APP_ID, 'cardDetailsInModal', (string)$value);
+				$this->config->setUserValue($userId, Application::APP_ID, 'cardDetailsInModal', (string)$value);
 				$result = $value;
 				break;
 			case 'cardIdBadge':
-				$this->config->setUserValue($this->getUserId(), Application::APP_ID, 'cardIdBadge', (string)$value);
+				$this->config->setUserValue($userId, Application::APP_ID, 'cardIdBadge', (string)$value);
 				$result = $value;
 				break;
 			case 'board':
@@ -161,7 +167,7 @@ class ConfigService {
 				if ($boardConfigKey === 'notify-due' && !in_array($value, [self::SETTING_BOARD_NOTIFICATION_DUE_ALL, self::SETTING_BOARD_NOTIFICATION_DUE_ASSIGNED, self::SETTING_BOARD_NOTIFICATION_DUE_OFF], true)) {
 					throw new BadRequestException('Board notification option must be one of: off, assigned, all');
 				}
-				$this->config->setUserValue($this->getUserId(), Application::APP_ID, $key, (string)$value);
+				$this->config->setUserValue($userId, Application::APP_ID, $key, (string)$value);
 				$result = $value;
 		}
 		return $result;
